@@ -3,6 +3,8 @@ use solana_program::account_info::AccountInfo;
 use solana_program::program_error::ProgramError;
 use switchboard_protos::protos::aggregator_state::mod_AggregatorState;
 use solana_program::pubkey::Pubkey;
+use borsh::BorshDeserialize;
+use std::convert::TryInto;
 
 pub use switchboard_protos::protos::aggregator_state::AggregatorState;
 pub use switchboard_protos::protos::aggregator_state::RoundResult;
@@ -41,6 +43,19 @@ pub fn get_aggregator_result(aggregator: &AggregatorState) -> Result<RoundResult
     maybe_round.ok_or(ProgramError::InvalidAccountData)
 }
 
+fn borsh_safe_deserialize<T: BorshDeserialize>(bytes: &[u8]) -> Result<T, ProgramError> {
+    let size_buf: &[u8] = &bytes[1..9];
+    let size = usize::from_le_bytes(size_buf.try_into().unwrap());
+    let buf = &bytes[9..size + 9];
+    let res = &buf[..size].to_vec();
+    T::try_from_slice(res).map_err(|_| ProgramError::InvalidAccountData)
+}
+
+pub fn get_feed_result(op_result: &AccountInfo) -> Result<RoundResult, ProgramError> {
+    let state_buffer = op_result.try_borrow_data()?;
+    borsh_safe_deserialize(&state_buffer)
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
@@ -70,12 +85,14 @@ mod tests {
                 min_confirmations: Some(10),
                 min_update_delay_seconds: Some(10),
                 locked: Some(false),
+                schedule: None,
             }),
             fulfillment_manager_pubkey: Some(Vec::new()),
             job_definition_pubkeys: Vec::new(),
             agreement: None,
             current_round_result: Some(current_round),
             last_round_result: Some(last_round),
+            parse_optimized_result_address: None,
         }
     }
 
